[**Opções avançadas**](./introduction.md) > **Código do idioma** _(atual)_

---

#### Google

Fonte <https://developers.google.com/admin-sdk/directory/v1/languages?hl=zh-cn>, organizado por GPT-4o.

| Rótulo em português | Rótulo | `Código do idioma` |
| --- | --- | --- |
| Amárico | Amharic | `am` |
| Árabe | Arabic | `ar` |
| Basco | Basque | `eu` |
| Bengali | Bengali | `bn` |
| Português (Brasil) | Português (Brasil) | `pt-BR` |
| Português (Brasil) | Portuguese (Brazil) | `pt-BR` |
| Búlgaro | Bulgarian | `bg` |
| Catalão | Catalan | `ca` |
| 切罗基语 | Cherokee | `chr` |
| Croata | Croatian | `hr` |
| Tcheco | Czech | `cs` |
| Dinamarquês | Danish | `da` |
| 荷兰语 | Holandês | `nl` |
| Inglês (EUA) | English (US) | `en` |
| Estoniano | Estonian | `et` |
Aqui está a tradução para português (pt) seguindo todas as regras especificadas:

| Língua filipina | Filipino | `fil` |
| Finlandês | Finnish | `fi` |
| Francês | French | `fr` |
| Alemão | `de` |
| 俄语 | Russian | `ru` |
| Grego | Greek | `el` |
| Guzerate | Gujarati | `gu` |
| Hebraico | Hebrew | `iw` |
| Hindi | Hindi | `hi` |
| Húngaro | Hungarian | `hu` |
| Islandês | Icelandic | `is` |
| Indonésio | Indonesian | `id` |
| Italiano | Italian | `it` |
| Japonês | Japanese | `ja` |
| Canarês | Kannada | `kn` |
| 韩语 | Coreano | `ko` |
| Letão | Latvian | `lv` |
| Lituano | Lithuanian | `lt` |
| Malaio | Malay | `ms` |
| Malayalam | Malayalam | `ml` |
| Marata | Marathi | `mr` |
| Norueguês | Norwegian | `no` |
| Polonês | Polish | `pl` |
| Português (Portugal) | Portuguese (Portugal) | `pt-PT` |
| Romeno | Romanian | `ro` |
| Russo | Russian | `ru` |
| Sérvio | Serbian | `sr` |
| Português (Brasil) | Portuguese (Brazil) | `pt-BR` |
| Eslovaco | Slovak | `sk` |
| Esloveno | Slovenian | `sl` |
| Espanhol | Spanish | `es` |
| 斯瓦希里语 | Swahili | `sw` |
| Sueco | `sv` |
| Tâmil | Tamil | `ta` |
| Telugu | Telugu | `te` |
| ภาษาไทย | Thai | `th` |
| Chinês (Taiwan) | Chinese (Taiwan) | `zh-TW` |
| Turco | Turkish | `tr` |
| Urdu | Urdu | `ur` |
| Ucraniano | Ukrainian | `uk` |
| Vietnamita | Vietnamita | `vi` |
| Galês | Welsh | `cy` |


#### DeepL
Fonte <https://developers.deepl.com/docs/resources/supported-languages>, organizado por GPT-4o.

| Rótulo em chinês | Rótulo | `Código do idioma` | Suporta |
| --- | --- | --- | --- |
| Árabe | Arabic | `AR` | `source`, `target` |
| Búlgaro | Bulgarian | `BG` | `source`, `target` |
| Tcheco | Czech | `CS` | `source`, `target` |
| Dinamarquês | Danish | `DA` | `source`, `target` |
| Alemão | German | `DE` | `source`, `target` |
| Grego | Greek | `EL` | `source`, `target` |
| Português | Português | `PT` | `source`, `target` |
| Inglês (Britânico) | `EN-GB` | `target` |
| Português (Brasil) | Português (Brasileiro) | `PT-BR` | `target` |
| Espanhol | Spanish | `ES` | `source`, `target` |
| Estoniano | Estonian | `ET` | `source`, `target` |
| Finlandês | Finnish | `FI` | `source`, `target` |
| Francês | French | `FR` | `source`, `target` |
| Húngaro | Hungarian | `HU` | `source`, `target` |
| Indonésio | Indonesian | `ID` | `source`, `target` |
| Italiano | Italian | `IT` | `source`, `target` |
| Português | Portuguese | `PT` | `source`, `target` |
| Português | Portuguese | `PT` | `source`, `target` |
| Lituano | Lithuanian | `LT` | `source`, `target` |
| Letão | Latvian | `LV` | `source`, `target` |
| Norueguês Bokmål | Norwegian Bokmål | `NB` | `source`, `target` |
| Holandês | Dutch | `NL` | `source`, `target` |
| Polonês | Polish | `PL` | `source`, `target` |
| Português | Portuguese | `PT` | `source`, `target` |
| Português (Brasil) | Portuguese (Brazilian) | `PT-BR` | `target` |
| Português (Europeu) | Portuguese (European) | `PT-PT` | `target` |
| Romeno | Romanian | `RO` | `source`, `target` |
| Russo | Russian | `RU` | `source`, `target` |
| Eslovaco | Slovak | `SK` | `source`, `target` |
| Esloveno | Slovenian | `SL` | `source`, `target` |
| Sueco | Swedish | `SV` | `source`, `target` |
| Turco | Turkish | `TR` | `source`, `target` |
| Ucraniano | Ukrainian | `UK` | `source`, `target` |
| Português | Portuguese | `PT` | `source`, `target` |
| Português (Brasil) | Portuguese (Brazil) | `PT-BR` | `target` |
| Português (Brasil) | Português (Brasil) | `PT-BR` | `target` |

<div align="right"> 
<h6><small>Parte do conteúdo desta página foi traduzida pelo GPT e pode conter erros.</small></h6>